package Builtin::Logged;

use parent qw(Log::Any::For::Builtins);

our $VERSION = '0.07'; # VERSION

1;
# ABSTRACT: Alias for Log::Any::For::Builtins

__END__

=pod

=encoding UTF-8

=head1 NAME

Builtin::Logged - Alias for Log::Any::For::Builtins

=head1 VERSION

This document describes version 0.07 of Builtin::Logged (from Perl distribution Builtin-Logged), released on 2014-05-17.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Builtin-Logged>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-Builtin-Logged>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Builtin-Logged>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
